@@ -1,5 +1,5 @@
 # For calculating scores for binary template matching 
-# Modified: 2014 MAR 19
+# Modified: 2014 NOV 7
 
 binMatch <-
 function(
@@ -9,6 +9,7 @@ function(
   show.prog=FALSE,        # If TRUE, progress is displayed during correlation calculations 
   warn=TRUE,              # If TRUE, will return a warning for time steps that don't match between the templates and the survey frequency-domain data.
   time.source='filename', # 'filename' or 'fileinfo' as the mtime source
+  write.wav=FALSE,        # Set to TRUE to allow creation of file of survey in working directory
   report.amp=FALSE,       # If TRUE, reports the on and off amplitudes (takes 3x as long) 
   ...                     # Additional arguments to the spectro function
 ) {
@@ -19,35 +20,32 @@ function(
 
   # Packages
   if(parallel) {
-    require(parallel) # NTS should replace with parallel::mclapply? or drop altogether?
-    lapplyfun<-function(X,FUN) mclapply(X,FUN,mc.cores=detectCores()-1)
+    lapplyfun<-function(X,FUN) parallel::mclapply(X,FUN,mc.cores=parallel::detectCores()-1)
   } else lapplyfun<-lapply
 
   # Start tracking time (after loading packages)
   t.start<-Sys.time()
 
   # Work with survey outside template loop
-  if(class(survey)=='character') { 
-    survey.name<-survey
-    file.ext<- gsub(".*\\.","",survey)
-    if(time.source=='fileinfo') {
+  # Creates a wav file for survey if it isn't already a file
+  survey<-getClip(survey,name=deparse(substitute(survey)),write.wav=write.wav)
+
+  if(time.source=='fileinfo') {
+     file.time<-file.info(survey)$mtime
+  } else if(time.source=='filename') {
+     survey.short<-strsplit(survey,'/')[[1]][length(strsplit(survey,'/')[[1]])]
+     date.time.info<-regmatches(survey.short,regexpr('[0-9]{4}-[0-9]{2}-[0-9]{2}[ _][0-9]{6}[ _][A-Z0-9]{1,7}',survey.short))
+     date.time.info<-gsub("_"," ",date.time.info)
+     if(length(date.time.info)==1 && nchar(date.time.info) %in% 19:23)
+       file.time<-as.POSIXct(substr(date.time.info,start=1,stop=17),tz=substr(date.time.info,start=19,stop=length(date.time.info)),format='%Y-%m-%d %H%M%S') 
+     else {
+       warning('time.source was set to \"filename\" but file name does not have date and time info, so using \"fileinfo\" instead')
        file.time<-file.info(survey)$mtime
-    } else if(time.source=='filename') {
-       survey.short<-strsplit(survey,'/')[[1]][length(strsplit(survey,'/')[[1]])]
-       date.time.info<-regmatches(survey.short,regexpr('[0-9]{4}-[0-9]{2}-[0-9]{2}[ _][0-9]{6}[ _][A-Z][SDM]T',survey.short))
-       date.time.info<-gsub("_"," ",date.time.info)
-       if(length(date.time.info)==1 && nchar(date.time.info)==21)
-         file.time<-as.POSIXct(substr(date.time.info,start=1,stop=17),tz=substr(date.time.info,start=19,stop=21),format='%Y-%m-%d %H%M%S') 
-       else {
-         warning('time.source was set to \"filename\" but file name does not have date and time info, so using \"fileinfo\" instead')
-         file.time<-file.info(survey)$mtime
-       }
-    }
-    if(file.ext=='wav') survey<-readWave(filename=survey) else if(file.ext=='mp3') survey<-readMP3(filename=survey) else stop('File extension must be wav or mp3')
-  } else if(class(survey)=='Wave') {
-    file.time<-NA 
-    survey.name<-'A Wave object'
-  } else stop(paste('Expect file path or wave object for survey argument, got',survey))
+     }
+  } else stop('time.source argument, ',time.source,' not recognized.')
+
+  survey.path<-survey
+  survey<-readClip(survey)
 
   # score.L is a list for storing results
   score.L<-list()
@@ -83,6 +81,10 @@ function(
     pt.off<-template@pt.off[,2:1]
     colnames(pt.off)<-c('frq','t')
 
+    # Make sure we have both pt.on and pt.off!
+    if(nrow(pt.on)==0) stop('You are missing "on" points in template ',i,'. This template cannot be used.')
+    if(nrow(pt.off)==0) stop('You are missing "off" points in template ',i,'. This template cannot be used.')
+
     # Adjust pt.on and pt.off if step sizes differ
     if(!isTRUE(all.equal(template@t.step,t.step,tolerance=t.step/1E4))) {
       pt.on[,'t']<-round(pt.on[,'t']*template@t.step/t.step)
@@ -166,10 +168,10 @@ function(
   }
 
   # Calculate total run time
-  t.run<-as.numeric(difftime(Sys.time(),t.start,units='secs'))
-  time.info<-c(t.exe=signif(t.run,4),RTfactor=paste(signif(t.survey/as.numeric(t.run,units='secs'),4),'x',sep=''))
+  t.run<-signif(as.numeric(difftime(Sys.time(),t.start,units='secs')),4)
+  time.info<-c(t.exe=as.character(t.run),RTfactor=paste(signif(t.survey/as.numeric(t.run,units='secs'),4),'x',sep=''))
 
   # Return results 
-  scores.obj<-new('templateScores',survey.name=survey.name,survey=survey,survey.data=survey.data,templates=templates@templates,scores=score.L,time=time.info)
+  scores.obj<-new('templateScores',survey.name=survey.path,survey=survey,survey.data=survey.data,templates=templates@templates,scores=score.L,time=time.info)
   return(scores.obj)
 }
