@@ -1,5 +1,5 @@
 # For calculating scores in spectrogram cross correlation
-# Modified: 2014 MAR 29
+# Modified: 2015 APRIL 22
 
 corMatch <-
 function(
@@ -10,6 +10,7 @@ function(
   cor.method='pearson',   # Method used by cor function (see ?cor)
   warn=TRUE,              # Set to FALSE to surpress warnings
   time.source='filename', # 'filename' or 'fileinfo' as the mtime source
+  write.wav=FALSE,        # Set to TRUE to allow creation of file of survey in working directory
   ...                     # Additional arguments to the spectro function
 ) {
 
@@ -19,42 +20,32 @@ function(
 
   # Packages
   if(parallel) {
-    require(parallel)
-    lapplyfun<-function(X,FUN) mclapply(X,FUN,mc.cores=detectCores())
+    lapplyfun<-function(X,FUN) parallel::mclapply(X,FUN,mc.cores=parallel::detectCores())
   } else lapplyfun<-lapply
 
   # Start tracking time (after loading packages)
   t.start<-Sys.time()
 
-  # NTS CAN WE USE GETCLIP HERE????
   # Work with survey outside template loop
-  # If survey is a Wave object, create a file from it
-  if(class(survey)=="Wave") {
-    fname<-paste0(deparse(substitute(survey)),".wav")
-    if(!file.exists(fname)) writeWave(survey,survey<-fname) else warning("Having trouble creating a wav file from ",deparse(substitute(survey)),"--file with name ",fname," already exists.",immediate=TRUE)
-  }
+  # Creates a wav file for survey if it isn't already a file
+  survey<-getClip(survey,name=deparse(substitute(survey)),write.wav=write.wav)
 
-  if(class(survey)=='character') { 
-    survey.name<-survey
-    file.ext<- gsub(".*\\.","",survey)
-    if(time.source=='fileinfo') {
+  if(time.source=='fileinfo') {
+     file.time<-file.info(survey)$mtime
+  } else if(time.source=='filename') {
+     survey.short<-strsplit(survey,'/')[[1]][length(strsplit(survey,'/')[[1]])]
+     date.time.info<-regmatches(survey.short,regexpr('[0-9]{4}-[0-9]{2}-[0-9]{2}[ _][0-9]{6}[ _][A-Z0-9]{1,7}',survey.short))
+     date.time.info<-gsub("_"," ",date.time.info)
+     if(length(date.time.info)==1 && nchar(date.time.info) %in% 19:23)
+       file.time<-as.POSIXct(substr(date.time.info,start=1,stop=17),tz=substr(date.time.info,start=19,stop=length(date.time.info)),format='%Y-%m-%d %H%M%S') 
+     else {
+       warning('time.source was set to \"filename\" but file name does not have date and time info, so using \"fileinfo\" instead')
        file.time<-file.info(survey)$mtime
-    } else if(time.source=='filename') {
-       survey.short<-strsplit(survey,'/')[[1]][length(strsplit(survey,'/')[[1]])]
-       date.time.info<-regmatches(survey.short,regexpr('[0-9]{4}-[0-9]{2}-[0-9]{2}[ _][0-9]{6}[ _][A-Z][SDM]T',survey.short))
-       date.time.info<-gsub("_"," ",date.time.info)
-       if(length(date.time.info)==1 && nchar(date.time.info)==21)
-         file.time<-as.POSIXct(substr(date.time.info,start=1,stop=17),tz=substr(date.time.info,start=19,stop=21),format='%Y-%m-%d %H%M%S') 
-       else {
-         warning('time.source was set to \"filename\" but file name does not have date and time info, so using \"fileinfo\" instead')
-         file.time<-file.info(survey)$mtime
-       }
-    }
-    if(file.ext=='wav') survey<-readWave(filename=survey) else if(file.ext=='mp3') survey<-readMP3(filename=survey) else stop('File extension must be wav or mp3')
-  } else if(class(survey)=='Wave') {
-    file.time<-NA 
-    survey.name<-'A Wave object'
-  } else stop(paste('Expect file path or wave object for survey argument, got',survey))
+     }
+  } else stop('time.source argument, ',time.source,' not recognized.')
+
+  survey.path<-survey
+  survey<-readClip(survey)
 
   # score.L is a list for storing results
   score.L<-list()
@@ -145,10 +136,10 @@ function(
   }
 
   # Calculate total run time
-  t.run<-Sys.time() - t.start
-  time.info<-c(t.exe=signif(t.run,4),RTfactor=paste(signif(t.survey/as.numeric(t.run,units='secs'),4),'x',sep=''))
+  t.run<-signif(as.numeric(difftime(Sys.time(),t.start,units='secs')),4)
+  time.info<-c(t.exe=as.character(t.run),RTfactor=paste(signif(t.survey/as.numeric(t.run,units='secs'),4),'x',sep=''))
 
   # Return results 
-  scores.obj<-new('templateScores',survey.name=survey.name,survey=survey,survey.data=survey.data,templates=templates@templates,scores=score.L,time=time.info)
+  scores.obj<-new('templateScores',survey.name=survey.path,survey=survey,survey.data=survey.data,templates=templates@templates,scores=score.L,time=time.info)
   return(scores.obj)
 }
