@@ -1,5 +1,5 @@
 # For writing correlation template lists to files
-# Modified: 2013 JUNE 13
+# Modified: 2015 APR 2
 
 writeCorTemplates <-
 function(
@@ -15,8 +15,7 @@ function(
    if(!file.exists(dir)) dir.create(dir)
 
    if(parallel) {
-      require(parallel)
-      lapplyfun<-function(X,FUN) mclapply(X,FUN,mc.cores=detectCores())
+      lapplyfun<-function(X,FUN) parallel::mclapply(X,FUN,mc.cores=parallel::detectCores())
    } else lapplyfun<-lapply
 
    names.templates<-names(templates@templates)
